#!/bin/bash
#
#############################################################
## 32or64.sh
## Determine whether a Progress installation is 32 or 64 bits
## Also reports the "bittedness" of the O/S, though this has
## only been tested under Linux
#
# Requires that $DLC be set, or that showcfg be findable via $PATH
# The exit value is 32 or 64.  There is normally a text output as
# well (e.g. "Progress is 64 bits"), but this may be suppressed
# with "-s" or expanded with "-v".
#
# On failure, exits with 0; this is the reverse of how most
# scripts work.  Sorry....
#
# Modification History
# 2013-05-20 ptf - Created
# 2013-07-23 ptf - Added O/S bit-size check; added "very verbose"
##############################################################
#  Copyright 2013 by Phil Freed / Frog Prince Consulting  (scripts@freed.com)
#  This script may be freely used, modified or distributed
#  The only requirement is that this copyright notice remain
#  with the script.
##############################################################
#
# Progress note:
# showcfg -B will give the "port number", which we use to get the info we need
#
# Output:
#   Configuration File:  /usr/dlc/progress.cfg
#
#         Company Name:  Generation Fifth Applications
#
#         Product Name:  4GL Development System
#    Installation Date:  Tue May 10 19:44:13 2011
#           User Limit:  1
#      Expiration Date:  None
#        Serial Number:  004189500
#      Control Numbers:  ??FSS - XQP6M - N4GYM
#       Version Number:  10.2B           
#        Machine Class:  KB
#          Port Number:  43
#  [....]
#
##########################
# 

if [ -n "$DLC" ]; then
  exe=$DLC/bin/showcfg
else
  exe=$( which showcfg )
  [ -z "$exe" ] && exe=/usr/dlc/bin/showcfg  ## last-ditch guess!
  if [ ! -x "$exe" ]; then
    echo
    echo 'ERROR!  Progress installation not found.  Please set $DLC or $PATH' >&2
    echo
    exit 0
  fi
fi

function SYNTAX {
  echo "SYNTAX:  $(basename $0) [-h|-s|-v|-vv]"
  echo "  -s is silent,  -v is verbose,  -vv is very verbose"
  echo "  -h returns this message."
  echo "  Exit value is 32 or 64, indicating the 'bittedness' of Progress."
  echo "  On failure, exits with 0, unlike most *nix utils."
  echo
  exit 0
}
 
silent=no
verbose=no
noiseLevel=1
while getopts shv arg; do
  case $arg in
    s)
      silent=yes
      noiseLevel=0
      ;;
    v)
      noiseLevel=$(( $noiseLevel + 1 ))
      verbose=yes
      ;;
    ?)
      echo
      SYNTAX
      ;;
  esac
done

if [ $silent = yes -a $verbose = yes ]; then
  echo
  echo "ERROR!  You cannot ask for both silent and verbose."
  echo
  SYNTAX
fi


## Extract Progress port number

port=$( ${dir}showcfg -B | awk '/Port Number/ { print $NF; nextfile }' )

case $port in
  34) info="HP 11 32 bit has 173 CD and 196 DVD media_id and port_number = 34" ;;

  36) info="HP 11 64 bit has 175 CD and 198 DVD media_id and port_number = 36" ;;
  40) info="HP Itanium2 has 186 CD and 197 DVD media_id and port_number = 40" ;;

  11) info="Sun Solaris SPARC 32 bit has 157 CD and 202 DVD media_id and port_number = 11" ;;
  39) info="Sun Solaris SPARC 64 bit has 182 CD and 203 DVD media_id and port_number = 39" ;;

  17) info="IBM AIX POWER 32 bit has 156 CD and 200 DVD media_id and port_number = 17" ;;
  37) info="IBM AIX POWER 64 bit has 187 CD and 201 DVD media_id and port_number = 37" ;;

  38) info="LINUX INTEL 32 bit has 178 CD and 204 DVD media_id and port_number = 38" ;;
  43) info="LINUX AMD 64 bit has 192 CD and 205 DVD media_id and port_number = 43" ;;
  45) info="LINUX POWERPC 64 bit has 209 CD and 210 DVD media_id and port_number = 45" ;;

  31) info="WINDOWS x86 32 bit has 146 CD and 195 DVD media_id and port_number = 31" ;;
  33) info="WINDOWS x86 64 bit has 212 CD and 218 DVD media_id and port_number = 33" ;;

  *)  echo "Uknown port number; Cannot determine anything about this Progress Release" >&2
      exit 0 ;;
esac

bit=$( echo "$info" | sed 's/ bit .*//; s/.* //')
OSbit=$( uname -m | fgrep _64 > /dev/null && echo 64 || echo 32 )

if [ "$noiseLevel" -ge 2 ]; then
  echo "PROGRESS installed in $(dirname $(dirname $exe ))"
  echo "- $info"
  echo "- $( uname -a )"
fi

if [ "$noiseLevel" -ge 3 ]; then
  if [ "$(uname)" = Linux ]; then
    cat /etc/*release
    echo -
  fi
fi

if [ "$noiseLevel" -ge 1 ]; then
  echo "Progress is $bit bits; OS is $OSbit bits"
fi

exit $bit
